@@ -1,7 +1,7 @@
 import bz2
 import gzip
 import os
-from typing import IO, Iterable, Iterator, Optional, Union
+from typing import IO, Any, Dict, Iterable, Iterator, Optional, Union
 
 from typing_extensions import Literal
 
@@ -14,15 +14,15 @@ __url__ = "https://github.com/MKuranowski/osmiter"
 __author__ = "Mikołaj Kuranowski"
 __copyright__ = "Copyright 2020-2022 Mikolaj Kuranowski"
 __license__ = "MIT"
-__version__ = "1.2.0"
+__version__ = "1.3.0"
 __email__ = "".join(chr(i) for i in [109, 107, 117, 114, 97, 110, 111, 119, 115, 107, 105, 32, 91,
                                      1072, 116, 93, 32, 103, 109, 97, 105, 108, 46, 99, 111, 109])
 
 
 def iter_from_osm(
-        source: Union[str, bytes, os.PathLike, int, IO[bytes]],
+        source: Union[str, bytes, os.PathLike[Any], int, IO[bytes]],
         file_format: Optional[Literal["xml", "gz", "bz2", "pbf"]] = None,
-        filter_attrs: Optional[Iterable[str]] = None) -> Iterator[dict]:
+        filter_attrs: Optional[Iterable[str]] = None) -> Iterator[Dict[str, Any]]:
     """Yields all items from provided source file.
 
     If source is a str/bytes/os.PathLike (path) the format will be guess based on file extension.
